@@ -15,10 +15,11 @@
  * limitations under the License.
  */
 
-/* $Id: Type1FontLoader.java 1761026 2016-09-16 12:50:43Z ssteiner $ */
+/* $Id$ */
 
 package org.apache.fop.fonts.type1;
 
+import java.awt.Rectangle;
 import java.awt.geom.RectangularShape;
 import java.io.IOException;
 import java.io.InputStream;
@@ -56,7 +57,7 @@ public class Type1FontLoader extends FontLoader {
 
     /**
      * Constructs a new Type 1 font loader.
-     * @param fontFileURI the URI to the PFB file of a Type 1 font
+     * @param fontUris the URI to the PFB file of a Type 1 font
      * @param embedded indicates whether the font is embedded or referenced
      * @param useKerning indicates whether to load kerning information if available
      * @param resourceResolver the font resolver used to resolve URIs
@@ -415,7 +416,10 @@ public class Type1FontLoader extends FontLoader {
             returnFont.setFirstChar(pfm.getFirstChar());
             returnFont.setLastChar(pfm.getLastChar());
             for (short i = pfm.getFirstChar(); i <= pfm.getLastChar(); i++) {
-                singleFont.setWidth(i, pfm.getCharWidth(i));
+                int cw = pfm.getCharWidth(i);
+                singleFont.setWidth(i, cw);
+                int[] bbox = pfm.getFontBBox();
+                singleFont.setBoundingBox(i, new Rectangle(bbox[0], bbox[1], cw, bbox[3]));
             }
             if (useKerning) {
                 returnFont.replaceKerningMap(pfm.getKerning());
